/*
 * Copyright (C) 2014-present Cloudflare, Inc.

 * This software may be modified and distributed under the terms
 * of the MIT license.  See the LICENSE file for details.
 */

'use strict';

const prototypal = require('es-class');
const auto = require('autocreate');

const Resource = require('../Resource');

/**
 * IPs represents the /ips API endpoint.
 *
 * @class IPs
 * @hideconstructor
 * @extends Resource
 */
module.exports = auto(
  prototypal({
    extends: Resource,
    path: 'ips',

    includeBasic: ['browse'],

    /**
     * browse returns a Promise of the current Cloudflare IPv4 and IPv6 addresses.
     *
     * @function browse
     * @memberof IPs
     * @instance
     * @async
     * @returns {Promise<Object>} The IPv4 and IPv6 addresses
     * @example
     * // logs the fetched IP addresses
     * cf.ips.browse(console.log)
     */
  })
);
